Changelog
---------

0.3.6
-----

* Update readme

0.3.5
-----

* Use vertical label in upper case

0.3.4
-----

* Add more status messages

0.3.3
-----

* Fix logical

0.3.1
-----

* Add locale folder to Manifest.in


0.3.0
-----

* Add Gettext/internationalization support

0.2.0
-----

* Bug Fixes
* Improve better UI
* Fix layout
* Change to use letters instead of only numbers

0.1.0 (2019-01-01)
------------------

* initial release
0.3.2
-----

* Fix locale file

0.3.1
-----

* Add locale folder to Manifest.in


0.3.0
-----

* Add Gettext/internationalization support

0.2.0
-----

* Bug Fixes
* Improve better UI
* Fix layout
* Change to use letters instead of only numbers

0.1.0 (2019-01-01)
------------------

* initial release
